@@ -19,8 +19,8 @@ from oslo_config import cfg
 from oslo_log import log
 
 from ironic_inspector.common.i18n import _LE, _LW
+from ironic_inspector.common import ironic as ir_utils
 from ironic_inspector import node_cache
-from ironic_inspector import utils
 
 
 CONF = cfg.CONF
@@ -30,6 +30,7 @@ CHAIN = None
 INTERFACE = None
 LOCK = semaphore.BoundedSemaphore()
 BASE_COMMAND = None
+BLACKLIST_CACHE = None
 
 
 def _iptables(*args, **kwargs):
@@ -58,7 +59,8 @@ def init():
     if not CONF.firewall.manage_firewall:
         return
 
-    global INTERFACE, CHAIN, NEW_CHAIN, BASE_COMMAND
+    global INTERFACE, CHAIN, NEW_CHAIN, BASE_COMMAND, BLACKLIST_CACHE
+    BLACKLIST_CACHE = None
     INTERFACE = CONF.firewall.dnsmasq_interface
     CHAIN = CONF.firewall.firewall_chain
     NEW_CHAIN = CHAIN + '_temp'
@@ -117,16 +119,25 @@ def update_filters(ironic=None):
 
     :param ironic: Ironic client instance, optional.
     """
+    global BLACKLIST_CACHE
+
     if not CONF.firewall.manage_firewall:
         return
 
     assert INTERFACE is not None
-    ironic = utils.get_client() if ironic is None else ironic
+    ironic = ir_utils.get_client() if ironic is None else ironic
 
     with LOCK:
         macs_active = set(p.address for p in ironic.port.list(limit=0))
         to_blacklist = macs_active - node_cache.active_macs()
+        if BLACKLIST_CACHE is not None and to_blacklist == BLACKLIST_CACHE:
+            LOG.debug('Not updating iptables - no changes in MAC list %s',
+                      to_blacklist)
+            return
+
         LOG.debug('Blacklisting active MAC\'s %s', to_blacklist)
+        # Force update on the next iteration if this attempt fails
+        BLACKLIST_CACHE = None
 
         # Clean up a bit to account for possible troubles on previous run
         _clean_up(NEW_CHAIN)
@@ -148,3 +159,6 @@ def update_filters(ironic=None):
         _iptables('-F', CHAIN, ignore=True)
         _iptables('-X', CHAIN, ignore=True)
         _iptables('-E', NEW_CHAIN, CHAIN)
+
+        # Cache result of successful iptables update
+        BLACKLIST_CACHE = to_blacklist
